@@ -9,5 +9,6 @@ from afloat import pca
 from afloat import shape
 from afloat import netcdf
 from afloat import xr
-from afloat import xrwrap
-from afloat import operational
\ No newline at end of file
+from afloat import config
+# from afloat import xrwrap
+# from afloat import operational
\ No newline at end of file
