@@ -9,7 +9,7 @@ import datetime
 import numpy as np
 import xarray as xr
 import pandas as pd
-from mpl_toolkits.axes_grid.inset_locator import inset_axes
+from mpl_toolkits.axes_grid1.inset_locator import inset_axes
 
 # from windrose import WindroseAxes # duplicated below now
 # import windrose # duplicated below now
@@ -704,7 +704,8 @@ def histogram(direction, var, bins, nsector, normed=False, blowto=False):
         direction = direction + 180.
         direction[direction >= 360.] = direction[direction >= 360.] - 360
 
-    table = histogram2d(x=var, y=direction, bins=[var_bins, dir_bins], normed=False)[0]
+    # table = histogram2d(x=var, y=direction, bins=[var_bins, dir_bins], normed=False)[0]
+    table = histogram2d(x=var, y=direction, bins=[var_bins, dir_bins], density=False)[0]
     # add the last value to the first to have the table of North winds
     table[:, 0] = table[:, 0] + table[:, -1]
     # and remove the last col
